@@ -1,5 +1,5 @@
 {- hpodder component
-Copyright (C) 2006 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2006-2007 John Goerzen <jgoerzen@complete.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ import Types
 import Text.Printf
 import Config
 import Database.HDBC
-import Control.Monad
+import Control.Monad hiding(forM_)
 import Utils
 import Data.Hash.MD5
 import System.FilePath
@@ -45,6 +45,15 @@ import Data.Progress.Tracker
 import Data.Progress.Meter
 import Control.Concurrent.MVar
 import Control.Concurrent
+import Data.Foldable(forM_)
+import System.Posix.IO(
+                       OpenMode(..),
+                       closeFd,
+                       defaultFileFlags,
+                       dupTo,
+                       openFd,
+                       stdOutput
+                      )
 
 d = debugM "download"
 i = infoM "download"
@@ -54,7 +63,7 @@ cmd = simpleCmd "download"
       "Downloads all pending podcast episodes (run update first)" helptext 
       [] cmd_worker
 
-cmd_worker gi ([], casts) =
+cmd_worker gi ([], casts) = lock $
     do podcastlist_raw <- getSelectedPodcasts (gdbh gi) casts
        let podcastlist = filter_disabled podcastlist_raw
        episodelist <- mapM (getEpisodes (gdbh gi)) podcastlist
@@ -135,8 +144,9 @@ procEpisode gi meter dltok ep name r =
 
 procSuccess gi ep tmpfp =
     do cp <- getCP ep idstr fnpart
-       let newfn = (strip . forceEither $ (get cp idstr "downloaddir")) ++ "/" ++
-                   (strip . forceEither $ (get cp idstr "namingpatt"))
+       let cfg = get cp idstr
+       let newfn = (strip $ forceEither $ cfg "downloaddir") ++ "/" ++
+                   (strip $ forceEither $ cfg "namingpatt")
        createDirectoryIfMissing True (fst . splitFileName $ newfn)
        finalfn <- if ((eptype ep) `elem` ["audio/mpeg", "audio/mp3", 
                                           "x-audio/mp3"]) && 
@@ -153,6 +163,8 @@ procSuccess gi ep tmpfp =
                                        "--WOAS", feedurl . podcast $ ep,
                                         -- "--WXXX", feedurl . podcast $ ep,
                                        finalfn] >>= id3result
+       forM_ (either (const Nothing) Just $ cfg "posthook")
+             (runHook finalfn)
        updateEpisode (gdbh gi) (ep {epstatus = Downloaded})
        commit (gdbh gi)
        
@@ -165,6 +177,28 @@ procSuccess gi ep tmpfp =
                  Terminated y -> w $ "\n   id3v2 terminated by signal " ++ show y
                  _ -> fail "Stopped unexpected"
 
+-- | Runs a hook script.
+runHook :: String -- ^ The name of the file to pass as an argument to the script.
+        -> String -- ^ The name of the script to invoke.
+        -> IO ()
+runHook fn script =
+    do child <- forkProcess runScript
+       status <- getProcessStatus True False child
+       case status of
+         Nothing -> fail "No status unexpected."
+         Just (Stopped _) -> fail "Stopped process unexpected."
+         Just (Terminated sig) -> fail (printf "Post-hook \"%s\" terminated by signal %s" script (show sig))
+         Just (Exited (ExitFailure code)) -> fail (printf "Post-hook \"%s\" failed with exit code %s" script (show code))
+         Just (Exited ExitSuccess) -> return ()
+    where runScript =
+              -- Open /dev/null, duplicate it to stdout, and close it.
+              do bracket (openFd "/dev/null" ReadOnly
+                                 Nothing defaultFileFlags)
+                         closeFd
+                         (\devNull ->
+                              do dupTo devNull stdOutput)
+                 executeFile script False [fn] Nothing
+
 getCP :: Episode -> String -> String -> IO ConfigParser
 getCP ep idstr fnpart =
     do cp <- loadCP
