@@ -1,5 +1,5 @@
 {- hpodder component
-Copyright (C) 2006 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2006-2007 John Goerzen <jgoerzen@complete.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ cmd = simpleCmd "import-ipodder"
        "Location of ipodder data directory (default ~/.ipodder)"] 
       cmd_worker
 
-cmd_worker gi (args, []) =
+cmd_worker gi (args, []) = lock $
     do ipodderpath <- case lookup "from" args of
                         Nothing -> do getAppUserDataDirectory "ipodder"
                         Just x -> return x
